models

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type APIError

type APIError struct {

	// An optional private error code whose values are undefined.
	Code int32 `json:"code,omitempty"`

	// An error message describing what went wrong.
	Message string `json:"message,omitempty"`
}

APIError api error

swagger:model apiError

func (*APIError) ContextValidate

func (m *APIError) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this api error based on context it is used

func (*APIError) MarshalBinary

func (m *APIError) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*APIError) UnmarshalBinary

func (m *APIError) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*APIError) Validate

func (m *APIError) Validate(formats strfmt.Registry) error

Validate validates this api error

type Configv1PageParams

type Configv1PageParams struct {

	// Sets the preferred number of items to return per page. If set to `0`, the
	// server will use its default value. Regardless of the value specified, clients
	// must never assume how many items will be returned.
	MaxSize int64 `json:"max_size,omitempty"`

	// An opaque page token that identifies which page the client should request.
	// An empty value indicates the first page.
	Token string `json:"token,omitempty"`
}

Configv1PageParams configv1 page params

swagger:model configv1PageParams

func (*Configv1PageParams) ContextValidate

func (m *Configv1PageParams) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this configv1 page params based on context it is used

func (*Configv1PageParams) MarshalBinary

func (m *Configv1PageParams) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Configv1PageParams) UnmarshalBinary

func (m *Configv1PageParams) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Configv1PageParams) Validate

func (m *Configv1PageParams) Validate(formats strfmt.Registry) error

Validate validates this configv1 page params

type Configv1PageResult

type Configv1PageResult struct {

	// An opaque page token that identifies the next page of items that the
	// client should request. An empty value indicates that there are no
	// more items to return.
	NextToken string `json:"next_token,omitempty"`
}

Configv1PageResult configv1 page result

swagger:model configv1PageResult

func (*Configv1PageResult) ContextValidate

func (m *Configv1PageResult) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this configv1 page result based on context it is used

func (*Configv1PageResult) MarshalBinary

func (m *Configv1PageResult) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Configv1PageResult) UnmarshalBinary

func (m *Configv1PageResult) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Configv1PageResult) Validate

func (m *Configv1PageResult) Validate(formats strfmt.Registry) error

Validate validates this configv1 page result

type GenericError

type GenericError interface{}

GenericError generic error

swagger:model genericError

type MetricUsageOrderBy

type MetricUsageOrderBy string

MetricUsageOrderBy metric usage order by

swagger:model MetricUsageOrderBy

const (

	// MetricUsageOrderByVALUABLE captures enum value "VALUABLE"
	MetricUsageOrderByVALUABLE MetricUsageOrderBy = "VALUABLE"

	// MetricUsageOrderByDPPS captures enum value "DPPS"
	MetricUsageOrderByDPPS MetricUsageOrderBy = "DPPS"

	// MetricUsageOrderByUTILITY captures enum value "UTILITY"
	MetricUsageOrderByUTILITY MetricUsageOrderBy = "UTILITY"

	// MetricUsageOrderByREFERENCES captures enum value "REFERENCES"
	MetricUsageOrderByREFERENCES MetricUsageOrderBy = "REFERENCES"

	// MetricUsageOrderByEXECUTIONS captures enum value "EXECUTIONS"
	MetricUsageOrderByEXECUTIONS MetricUsageOrderBy = "EXECUTIONS"

	// MetricUsageOrderByUNIQUEVALUES captures enum value "UNIQUE_VALUES"
	MetricUsageOrderByUNIQUEVALUES MetricUsageOrderBy = "UNIQUE_VALUES"

	// MetricUsageOrderByUNIQUEUSERS captures enum value "UNIQUE_USERS"
	MetricUsageOrderByUNIQUEUSERS MetricUsageOrderBy = "UNIQUE_USERS"
)

func NewMetricUsageOrderBy

func NewMetricUsageOrderBy(value MetricUsageOrderBy) *MetricUsageOrderBy

func (MetricUsageOrderBy) ContextValidate

func (m MetricUsageOrderBy) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this metric usage order by based on context it is used

func (MetricUsageOrderBy) Pointer

Pointer returns a pointer to a freshly-allocated MetricUsageOrderBy.

func (MetricUsageOrderBy) Validate

func (m MetricUsageOrderBy) Validate(formats strfmt.Registry) error

Validate validates this metric usage order by

type MetricUsageQueryExecutionCountsByType

type MetricUsageQueryExecutionCountsByType struct {

	// dashboard
	Dashboard int32 `json:"dashboard,omitempty"`

	// explorer
	Explorer int32 `json:"explorer,omitempty"`

	// external
	External int32 `json:"external,omitempty"`
}

MetricUsageQueryExecutionCountsByType metric usage query execution counts by type

swagger:model MetricUsageQueryExecutionCountsByType

func (*MetricUsageQueryExecutionCountsByType) ContextValidate

func (m *MetricUsageQueryExecutionCountsByType) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this metric usage query execution counts by type based on context it is used

func (*MetricUsageQueryExecutionCountsByType) MarshalBinary

func (m *MetricUsageQueryExecutionCountsByType) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MetricUsageQueryExecutionCountsByType) UnmarshalBinary

func (m *MetricUsageQueryExecutionCountsByType) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MetricUsageQueryExecutionCountsByType) Validate

Validate validates this metric usage query execution counts by type

type MetricUsageReferenceCountsByType

type MetricUsageReferenceCountsByType struct {

	// aggregation rules
	AggregationRules int32 `json:"aggregation_rules,omitempty"`

	// dashboards
	Dashboards int32 `json:"dashboards,omitempty"`

	// drop rules
	DropRules int32 `json:"drop_rules,omitempty"`

	// monitors
	Monitors int32 `json:"monitors,omitempty"`

	// recording rules
	RecordingRules int32 `json:"recording_rules,omitempty"`
}

MetricUsageReferenceCountsByType metric usage reference counts by type

swagger:model MetricUsageReferenceCountsByType

func (*MetricUsageReferenceCountsByType) ContextValidate

func (m *MetricUsageReferenceCountsByType) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this metric usage reference counts by type based on context it is used

func (*MetricUsageReferenceCountsByType) MarshalBinary

func (m *MetricUsageReferenceCountsByType) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MetricUsageReferenceCountsByType) UnmarshalBinary

func (m *MetricUsageReferenceCountsByType) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MetricUsageReferenceCountsByType) Validate

Validate validates this metric usage reference counts by type

type ProtobufAny

type ProtobufAny struct {

	// at type
	AtType string `json:"@type,omitempty"`

	// protobuf any
	ProtobufAny map[string]interface{} `json:"-"`
}

ProtobufAny protobuf any

swagger:model protobufAny

func (*ProtobufAny) ContextValidate

func (m *ProtobufAny) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this protobuf any based on context it is used

func (*ProtobufAny) MarshalBinary

func (m *ProtobufAny) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (ProtobufAny) MarshalJSON

func (m ProtobufAny) MarshalJSON() ([]byte, error)

MarshalJSON marshals this object with additional properties into a JSON object

func (*ProtobufAny) UnmarshalBinary

func (m *ProtobufAny) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*ProtobufAny) UnmarshalJSON

func (m *ProtobufAny) UnmarshalJSON(data []byte) error

UnmarshalJSON unmarshals this object with additional properties from JSON

func (*ProtobufAny) Validate

func (m *ProtobufAny) Validate(formats strfmt.Registry) error

Validate validates this protobuf any

type RuleEvaluationRuleType

type RuleEvaluationRuleType string

RuleEvaluationRuleType rule evaluation rule type

swagger:model RuleEvaluationRuleType

const (

	// RuleEvaluationRuleTypeMONITOR captures enum value "MONITOR"
	RuleEvaluationRuleTypeMONITOR RuleEvaluationRuleType = "MONITOR"

	// RuleEvaluationRuleTypeRECORDING captures enum value "RECORDING"
	RuleEvaluationRuleTypeRECORDING RuleEvaluationRuleType = "RECORDING"
)

func NewRuleEvaluationRuleType

func NewRuleEvaluationRuleType(value RuleEvaluationRuleType) *RuleEvaluationRuleType

func (RuleEvaluationRuleType) ContextValidate

func (m RuleEvaluationRuleType) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this rule evaluation rule type based on context it is used

func (RuleEvaluationRuleType) Pointer

Pointer returns a pointer to a freshly-allocated RuleEvaluationRuleType.

func (RuleEvaluationRuleType) Validate

func (m RuleEvaluationRuleType) Validate(formats strfmt.Registry) error

Validate validates this rule evaluation rule type

type Statev1ListMetricUsagesByLabelNameResponse

type Statev1ListMetricUsagesByLabelNameResponse struct {

	// page
	Page *Configv1PageResult `json:"page,omitempty"`

	// usages
	Usages []*Statev1MetricUsageByLabelName `json:"usages"`
}

Statev1ListMetricUsagesByLabelNameResponse statev1 list metric usages by label name response

swagger:model statev1ListMetricUsagesByLabelNameResponse

func (*Statev1ListMetricUsagesByLabelNameResponse) ContextValidate

ContextValidate validate this statev1 list metric usages by label name response based on the context it is used

func (*Statev1ListMetricUsagesByLabelNameResponse) MarshalBinary

func (m *Statev1ListMetricUsagesByLabelNameResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1ListMetricUsagesByLabelNameResponse) UnmarshalBinary

func (m *Statev1ListMetricUsagesByLabelNameResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1ListMetricUsagesByLabelNameResponse) Validate

Validate validates this statev1 list metric usages by label name response

type Statev1ListMetricUsagesByMetricNameResponse

type Statev1ListMetricUsagesByMetricNameResponse struct {

	// page
	Page *Configv1PageResult `json:"page,omitempty"`

	// usages
	Usages []*Statev1MetricUsageByMetricName `json:"usages"`
}

Statev1ListMetricUsagesByMetricNameResponse statev1 list metric usages by metric name response

swagger:model statev1ListMetricUsagesByMetricNameResponse

func (*Statev1ListMetricUsagesByMetricNameResponse) ContextValidate

ContextValidate validate this statev1 list metric usages by metric name response based on the context it is used

func (*Statev1ListMetricUsagesByMetricNameResponse) MarshalBinary

func (m *Statev1ListMetricUsagesByMetricNameResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1ListMetricUsagesByMetricNameResponse) UnmarshalBinary

func (m *Statev1ListMetricUsagesByMetricNameResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1ListMetricUsagesByMetricNameResponse) Validate

Validate validates this statev1 list metric usages by metric name response

type Statev1ListRuleEvaluationsResponse

type Statev1ListRuleEvaluationsResponse struct {

	// page
	Page *Configv1PageResult `json:"page,omitempty"`

	// rule evaluations
	RuleEvaluations []*Statev1RuleEvaluation `json:"rule_evaluations"`
}

Statev1ListRuleEvaluationsResponse statev1 list rule evaluations response

swagger:model statev1ListRuleEvaluationsResponse

func (*Statev1ListRuleEvaluationsResponse) ContextValidate

func (m *Statev1ListRuleEvaluationsResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 list rule evaluations response based on the context it is used

func (*Statev1ListRuleEvaluationsResponse) MarshalBinary

func (m *Statev1ListRuleEvaluationsResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1ListRuleEvaluationsResponse) UnmarshalBinary

func (m *Statev1ListRuleEvaluationsResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1ListRuleEvaluationsResponse) Validate

Validate validates this statev1 list rule evaluations response

type Statev1MetricUsage

type Statev1MetricUsage struct {

	// query execution counts by type
	QueryExecutionCountsByType *MetricUsageQueryExecutionCountsByType `json:"query_execution_counts_by_type,omitempty"`

	// reference counts by type
	ReferenceCountsByType *MetricUsageReferenceCountsByType `json:"reference_counts_by_type,omitempty"`

	// total query executions
	TotalQueryExecutions int32 `json:"total_query_executions,omitempty"`

	// total references
	TotalReferences int32 `json:"total_references,omitempty"`

	// total unique users
	TotalUniqueUsers int32 `json:"total_unique_users,omitempty"`

	// utility score
	UtilityScore float64 `json:"utility_score,omitempty"`
}

Statev1MetricUsage statev1 metric usage

swagger:model statev1MetricUsage

func (*Statev1MetricUsage) ContextValidate

func (m *Statev1MetricUsage) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 metric usage based on the context it is used

func (*Statev1MetricUsage) MarshalBinary

func (m *Statev1MetricUsage) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1MetricUsage) UnmarshalBinary

func (m *Statev1MetricUsage) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1MetricUsage) Validate

func (m *Statev1MetricUsage) Validate(formats strfmt.Registry) error

Validate validates this statev1 metric usage

type Statev1MetricUsageByLabelName

type Statev1MetricUsageByLabelName struct {

	// dpps
	Dpps float64 `json:"dpps,omitempty"`

	// label name
	LabelName string `json:"label_name,omitempty"`

	// Percent of persisted series observed to have the label name.
	// Returns in format: [0.0, 100.0]
	PercentOfSeriesWithLabelName float64 `json:"percent_of_series_with_label_name,omitempty"`

	// total unique values
	TotalUniqueValues int32 `json:"total_unique_values,omitempty"`

	// usage
	Usage *Statev1MetricUsage `json:"usage,omitempty"`
}

Statev1MetricUsageByLabelName statev1 metric usage by label name

swagger:model statev1MetricUsageByLabelName

func (*Statev1MetricUsageByLabelName) ContextValidate

func (m *Statev1MetricUsageByLabelName) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 metric usage by label name based on the context it is used

func (*Statev1MetricUsageByLabelName) MarshalBinary

func (m *Statev1MetricUsageByLabelName) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1MetricUsageByLabelName) UnmarshalBinary

func (m *Statev1MetricUsageByLabelName) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1MetricUsageByLabelName) Validate

func (m *Statev1MetricUsageByLabelName) Validate(formats strfmt.Registry) error

Validate validates this statev1 metric usage by label name

type Statev1MetricUsageByMetricName

type Statev1MetricUsageByMetricName struct {

	// dpps
	Dpps float64 `json:"dpps,omitempty"`

	// metric name
	MetricName string `json:"metric_name,omitempty"`

	// usage
	Usage *Statev1MetricUsage `json:"usage,omitempty"`
}

Statev1MetricUsageByMetricName statev1 metric usage by metric name

swagger:model statev1MetricUsageByMetricName

func (*Statev1MetricUsageByMetricName) ContextValidate

func (m *Statev1MetricUsageByMetricName) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 metric usage by metric name based on the context it is used

func (*Statev1MetricUsageByMetricName) MarshalBinary

func (m *Statev1MetricUsageByMetricName) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1MetricUsageByMetricName) UnmarshalBinary

func (m *Statev1MetricUsageByMetricName) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1MetricUsageByMetricName) Validate

func (m *Statev1MetricUsageByMetricName) Validate(formats strfmt.Registry) error

Validate validates this statev1 metric usage by metric name

type Statev1MetricUsageOrder

type Statev1MetricUsageOrder struct {

	// ascending
	Ascending bool `json:"ascending,omitempty"`

	// by
	By MetricUsageOrderBy `json:"by,omitempty"`
}

Statev1MetricUsageOrder statev1 metric usage order

swagger:model statev1MetricUsageOrder

func (*Statev1MetricUsageOrder) ContextValidate

func (m *Statev1MetricUsageOrder) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 metric usage order based on the context it is used

func (*Statev1MetricUsageOrder) MarshalBinary

func (m *Statev1MetricUsageOrder) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1MetricUsageOrder) UnmarshalBinary

func (m *Statev1MetricUsageOrder) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1MetricUsageOrder) Validate

func (m *Statev1MetricUsageOrder) Validate(formats strfmt.Registry) error

Validate validates this statev1 metric usage order

type Statev1RuleEvaluation

type Statev1RuleEvaluation struct {

	// The number of rule evaluation issues occurred over last 5 minutes.
	Count int32 `json:"count,omitempty"`

	// Timestamp when the rule evaluation issues are detected.
	// Rule evaluations issues are aggregated over last 5 minute leading up to detected_at.
	// Format: date-time
	DetectedAt strfmt.DateTime `json:"detected_at,omitempty"`

	// Detailed message related to rule evaluation issue. See "Admin > Evaluation failures" in the Chronosphere documentation for more information.
	Message string `json:"message,omitempty"`

	// Unique identifier of the rule.
	RuleSlug string `json:"rule_slug,omitempty"`

	// rule type
	RuleType RuleEvaluationRuleType `json:"rule_type,omitempty"`
}

Statev1RuleEvaluation statev1 rule evaluation

swagger:model statev1RuleEvaluation

func (*Statev1RuleEvaluation) ContextValidate

func (m *Statev1RuleEvaluation) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this statev1 rule evaluation based on the context it is used

func (*Statev1RuleEvaluation) MarshalBinary

func (m *Statev1RuleEvaluation) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Statev1RuleEvaluation) UnmarshalBinary

func (m *Statev1RuleEvaluation) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Statev1RuleEvaluation) Validate

func (m *Statev1RuleEvaluation) Validate(formats strfmt.Registry) error

Validate validates this statev1 rule evaluation

Jump to